0.9.9 API documentation: polar_coordinates.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
polar_coordinates.hpp File Reference

GLM_GTX_polar_coordinates More...

Go to the source code of this file.

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 3, T, Q > | euclidean (vec< 2, T, Q > const &polar)
| Convert Polar to Euclidean coordinates. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 3, T, Q > | polar (vec< 3, T, Q > const &euclidean)
| Convert Euclidean to Polar coordinates, x is the xz distance, y, the latitude and z the longitude. More...

## Detailed Description

GLM_GTX_polar_coordinates

See also
  Core features (dependence)

Definition in file polar_coordinates.hpp.